OC.L10N.register(
    "oauth2",
    {
    "Your client is not authorized to connect. Please inform the administrator of your client." : "Your client is not authorised to connect. Please inform the administrator of your client.",
    "Your redirect URL needs to be a full URL for example: https://yourdomain.com/path" : "Your redirect URL needs to be a full URL for example: https://yourdomain.com/path",
    "OAuth 2.0" : "OAuth 2.0",
    "Allows OAuth2 compatible authentication from other web applications." : "Allows OAuth2 compatible authentication from other web applications.",
    "The OAuth2 app allows administrators to configure the built-in authentication workflow to also allow OAuth2 compatible authentication from other web applications." : "The OAuth2 app allows administrators to configure the built-in authentication workflow to also allow OAuth2 compatible authentication from other web applications.",
    "OAuth 2.0 clients" : "OAuth 2.0 clients",
    "OAuth 2.0 allows external services to request access to {instanceName}." : "OAuth 2.0 allows external services to request access to {instanceName}.",
    "Name" : "Name",
    "Redirection URI" : "Redirection URI",
    "Client Identifier" : "Client Identifier",
    "Secret key" : "Secret key",
    "Delete client" : "Delete client",
    "Make sure you store the secret key, it cannot be recovered." : "Make sure you store the secret key, it cannot be recovered.",
    "Add client" : "Add client",
    "Add" : "Add",
    "Show client secret" : "Show client secret",
    "Hide client secret" : "Hide client secret",
    "Delete" : "Delete"
},
"nplurals=2; plural=(n != 1);");
